@@ -3,11 +3,14 @@ import logging
 from functools import wraps
 
 
-def trace(logger: logging.Logger):
+def trace(logger: logging.Logger, capture_args=True):
     """Decorator to trace the execution time of a Python function or method.
 
     Args:
         logger (logging.Logger): The logger instance for the function's module.
+        capture_args (bool, optional): When tracing the function, capture the 
+            arguments provided to the function and add them to the log message.
+            Defaults to True.
 
     Example:
 
@@ -28,7 +31,10 @@ def trace(logger: logging.Logger):
     def _trace_time(func):
         @wraps(func)
         def timed(*args, **kw_args):
-            func_str_repr = f'{func.__module__}:{func.__name__}({args!r},{kw_args!r})'
+            if capture_args:
+                func_str_repr = f'{func.__module__}:{func.__name__}({args!r},{kw_args!r})'
+            else:
+                func_str_repr = f'{func.__module__}:{func.__name__}(...)'
             logger.debug(f'Starting: {func_str_repr}')
             start = time.time()
             result = func(*args, **kw_args)
